==> openshift-model-installer-5.12.3-sources.jar: io/fabric8/openshift/api/model/installer/alibabacloud/v1/MachinePoolBuilder.java <==
package io.fabric8.openshift.api.model.installer.alibabacloud.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachinePoolBuilder extends io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolFluentImpl<io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePool,io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolBuilder>{
  public MachinePoolBuilder() {
    this(false);
  }
  public MachinePoolBuilder(java.lang.Boolean validationEnabled) {
    this(new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolBuilder(io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolFluent<?> fluent,io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePool instance) {
    this(fluent, instance, false);
  }
  public MachinePoolBuilder(io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolFluent<?> fluent,io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePool instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageID(instance.getImageID()); 
    fluent.withInstanceType(instance.getInstanceType()); 
    fluent.withSystemDiskCategory(instance.getSystemDiskCategory()); 
    fluent.withSystemDiskSize(instance.getSystemDiskSize()); 
    fluent.withZones(instance.getZones()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolBuilder(io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePool instance) {
    this(instance,false);
  }
  public MachinePoolBuilder(io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePool instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageID(instance.getImageID()); 
    this.withInstanceType(instance.getInstanceType()); 
    this.withSystemDiskCategory(instance.getSystemDiskCategory()); 
    this.withSystemDiskSize(instance.getSystemDiskSize()); 
    this.withZones(instance.getZones()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePoolFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.installer.alibabacloud.v1.MachinePool build() {
    MachinePool buildable = new MachinePool(fluent.getImageID(),fluent.getInstanceType(),fluent.getSystemDiskCategory(),fluent.getSystemDiskSize(),fluent.getZones());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachinePoolBuilder that = (MachinePoolBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-installer-6.2.0-sources.jar: io/fabric8/openshift/api/model/installer/alibabacloud/v1/MachinePoolBuilder.java <==
package io.fabric8.openshift.api.model.installer.alibabacloud.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolBuilder extends MachinePoolFluentImpl<MachinePoolBuilder> implements VisitableBuilder<MachinePool,MachinePoolBuilder>{
  public MachinePoolBuilder() {
    this(false);
  }
  public MachinePoolBuilder(Boolean validationEnabled) {
    this(new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance) {
    this(fluent, instance, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageID(instance.getImageID()); 
    fluent.withInstanceType(instance.getInstanceType()); 
    fluent.withSystemDiskCategory(instance.getSystemDiskCategory()); 
    fluent.withSystemDiskSize(instance.getSystemDiskSize()); 
    fluent.withZones(instance.getZones()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolBuilder(MachinePool instance) {
    this(instance,false);
  }
  public MachinePoolBuilder(MachinePool instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageID(instance.getImageID()); 
    this.withInstanceType(instance.getInstanceType()); 
    this.withSystemDiskCategory(instance.getSystemDiskCategory()); 
    this.withSystemDiskSize(instance.getSystemDiskSize()); 
    this.withZones(instance.getZones()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachinePoolFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePool build() {
    MachinePool buildable = new MachinePool(fluent.getImageID(),fluent.getInstanceType(),fluent.getSystemDiskCategory(),fluent.getSystemDiskSize(),fluent.getZones());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
